meta-google: gbmc-bridge: keep dhcp running longer

This is to make sure that dhcp runs for a while after nic is fully
functional.

Change-Id: I32c0e516bdb6a5aa33728266e8a58b9555d3e0ce
Signed-off-by: Yuxiao Zhang <yuxiaozhang@google.com>
diff --git a/meta-google/recipes-google/networking/gbmc-bridge/gbmc-br-dhcp-term.sh b/meta-google/recipes-google/networking/gbmc-bridge/gbmc-br-dhcp-term.sh
index 1ba0ac3..0a821ea 100644
--- a/meta-google/recipes-google/networking/gbmc-bridge/gbmc-br-dhcp-term.sh
+++ b/meta-google/recipes-google/networking/gbmc-bridge/gbmc-br-dhcp-term.sh
@@ -48,7 +48,7 @@
 
 # We need to guarantee we wait at least 5 minutes from reachable in
 # case networking just came up
-wait_min=5
+wait_min=10
 echo "Network is reachable, waiting $wait_min min" >&2
 sleep $((60 * wait_min))
 
@@ -87,7 +87,7 @@
   # The process is already stopped, we are done
   [[ "$activestr" == 'inactive' ]] && exit
 
   # If the process is running, give it at least 5 minutes from when it started
   cur_s="$(cut -d' ' -f1 /proc/uptime)"
   # Remove floating point if applied since bash can't perform float arithmetic
   cur_s="${cur_s%.*}"
@@ -87,7 +87,7 @@
   [[ "$activestr" == 'inactive' ]] && exit
 
-  # If the process is running, give it at least 5 minutes from when it started
+  # If the process is running, give it at least 10 minutes from when it started
   cur_s="$(cut -d' ' -f1 /proc/uptime)"
   # Remove floating point if applied since bash can't perform float arithmetic